% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/cate.R
\name{crr}
\alias{crr}
\title{Conditional Relative Risk estimation}
\usage{
crr(
  treatment,
  response_model,
  propensity_model,
  importance_model,
  contrast = c(1, 0),
  data,
  nfolds = 5,
  type = "dml1",
  ...
)
}
\arguments{
\item{treatment}{formula specifying treatment and variables to condition on}

\item{response_model}{SL object}

\item{propensity_model}{SL object}

\item{importance_model}{SL object}

\item{contrast}{treatment contrast (default 1 vs 0)}

\item{data}{data.frame}

\item{nfolds}{Number of folds}

\item{type}{'dml1' or 'dml2'}

\item{...}{additional arguments to SuperLearner}
}
\value{
cate.targeted object
}
\description{
Conditional Relative Risk estimation via Double Machine Learning
}
\examples{
sim1 <- function(n=1e4,
                 seed=NULL,
                 return_model=FALSE, ...){
suppressPackageStartupMessages(require("lava"))
if (!is.null(seed)) set.seed(seed)
m <- lava::lvm()
distribution(m, ~x) <- gaussian.lvm()
distribution(m, ~v) <- gaussian.lvm(mean = 10)
distribution(m, ~a) <- binomial.lvm("logit")
regression(m, "a") <- function(v, x){.1*v + x}
distribution(m, "y") <- gaussian.lvm()
regression(m, "y") <- function(a, v, x){v+x+a*x+a*v*v}
if (return_model) return(m)
lava::sim(m, n = n)
}

d <- sim1(n = 2e3, seed = 1)
if (require("SuperLearner",quietly=TRUE)) {
  e <- crr(data=d,
           type = "dml2",
           treatment = a ~ v,
           response_model = ML(y~ a*(x + v + I(v^2))),
           importance_model = ML(D_ ~ v + I(v^2)),
           propensity_model = ML(a ~ x + v + I(v^2), family=binomial),
           nfolds = 2)
  summary(e) # the true parameters are c(1,1)
}

}
\author{
Klaus Kähler Holst & Andreas Nordland
}
